@@ -1,5 +1,5 @@
 from .fluvii_app import FluviiApp, FluviiTableApp
-from .custom_exceptions import WrappedSignals
+from .exceptions import WrappedSignals
 from .logging_utils import init_logger
 
 init_logger(__name__)
